@@ -1,3 +1,4 @@
+"""Class to create a server."""
 import logging
 from http.server import HTTPServer
 from typing import Optional
@@ -6,9 +7,8 @@ from monzo.viewer.handler import Handler
 
 
 class Server(object):
-    """
-    Create and run a server.
-    """
+    """Create and run a server."""
+
     __slots__ = (
         '_handler',
         '_host',
@@ -30,9 +30,7 @@ class Server(object):
         self.run()
 
     def run(self) -> None:
-        """
-        Start the server daemon.
-        """
+        """Start the server daemon."""
         server_address = (self._host, self._port)
         self._server = HTTPServer(server_address, self._handler)
         logging.debug(f'Starting Monzo server on http://{server_address[0]}:{server_address[1]}')
